import os
from setuptools import setup, find_packages

def read_version():
    init_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), "src", "cve_vulnerability_scanner", "__init__.py")
    
    with open(init_path, "r", encoding="utf-8") as f:
        for line in f:
            if line.startswith("__version__"):
                return eval(line.split("=")[1].strip())
    raise RuntimeError("無法找到版本資訊")

# 讀取 README
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="cve-vulnerability-scanner",
    version=read_version(),
    author="changyy",
    author_email="changyy.csie@gmail.com",
    description="A Python tool that scans software dependencies for known vulnerabilities using NIST's National Vulnerability Database (NVD)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/changyy/py-cve-vulnerability-scanner",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Software Distribution",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    python_requires=">=3.8",
    install_requires=[
        "requests>=2.25.0",     # 用於 API 請求
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov>=2.0",
            "black>=22.0",
            "flake8>=3.9",
            "mypy>=0.900",
        ],
    },
    entry_points={
        "console_scripts": [
            "cve-vulnerability-scanner=cve_vulnerability_scanner.main:main",
        ],
    },
    package_data={
        "cve_vulnerability_scanner": ["py.typed"],
    },
    project_urls={
        "Bug Tracker": "https://github.com/changyy/py-cve-vulnerability-scanner/issues",
        "Documentation": "https://github.com/changyy/py-cve-vulnerability-scanner#readme",
        "Source Code": "https://github.com/changyy/py-cve-vulnerability-scanner",
    },
    keywords="cve security vulnerability scanner nvd nist",
)
